import {getUrl, modelLogin, sandBox, is} from '../../../es6/myapp.js';

Page({
  data: {
    detail: {},
    join: [{
      name:'',
      mobile: '',
      age: ''
    }]
  },
  onLoad(e) {
    let id = e.id
    this.getActivityInfo(id)
  },
  // 获取活动详情
  getActivityInfo(id) {
    wx.showLoading({
        title: '加载中'
      })
    sandBox.get({
      api: 'api/course/activities/'+id
    }).then(res => {
      wx.hideLoading()
      res = res.data
      if (res.status) {
         this.setData({
           detail: res.data
         })
      } else {
        wx.showToast({
          title: "获取活动列表失败",
          icon: 'none'
        });
      }
    }).catch(e => {
      wx.hideLoading()
      wx.showToast({
        title: "获取活动详情失败",
        icon: 'none'
      });
    })
  },
  // 添加报名人信息
  addJoin() {
    this.setData({
      join: this.data.join.concat([{
        name:'',
        mobile: '',
        age: ''
      }])
    })
  },
  // 双向绑定
  moduleInput(e) {
    let index = e.currentTarget.dataset.index
    let key = e.currentTarget.dataset.key
    let value = e.detail.value
    this.data.join[index][key] = value
    this.setData({
      join: this.data.join
    })
  },
  // 报名
  submit() {
    let _this = this
    modelLogin(getUrl(), (token) => {
      // 验证
      let flag
      this.data.join.forEach(item => {
        if(!item.name || !item.age || !item.mobile) {
          flag = {
            message:'请填写完整信息',
            status: false 
          }
          return false
        } else {
          if(!is.mobile(item.mobile)) {
            flag = {
              message:'请填写正确的手机号',
              status: false 
            }
            return false
          } else if (!is.age(item.age)) {
            flag = {
              message:'请填写真实年龄',
              status: false 
            }
          } else {
            flag = {
              message:'',
              status: true 
            }
          }
        }
      })
      if(!flag.status) {
        wx.showToast({
          title: flag.message,
          icon: 'none'
        })
      } else {
        wx.showLoading({
        title: '加载中'
      })
        sandBox.post({
          api: 'api/course/activity/upload',
          data: {
            join: _this.data.join,
            act_id: _this.data.detail.id
          },
          header: {
            authorization:token
          }
        }).then(res => {
          wx.hideLoading()
          res = res.data
          if(res.status) {
            wx.showToast({
              title: '报名成功',
              icon: 'success'
            })
            // 重置
            _this.setData({
              join: [{
                name:'',
                mobile: '',
                age: ''
              }]
            })
          } else {
            wx.showToast({
              title: (typeof res.message === "string") ? res.message : '报名失败',
              icon: 'none'
            })
          }
        }).catch(e => {
          wx.hideLoading()
          wx.showToast({
            title: '报名失败',
            icon: 'none'
          })
        })
      }
    })
  },
  // 删除报名
  deleteJoin(e) {
    let index = e.currentTarget.dataset.index
    this.data.join.splice(index, 1)

    this.setData({
      join: this.data.join
    })
  }
})