import { sandBox, cookieStorage, getUrl, modelLogin } from '../../../es6/myapp.js';

Page({
  data: {
    searchKeyword: '',
    searchList: [],
    historyList: []
  },
  onShow() {
    // 初始化
    this.setData({
      searchKeyword: '',
      searchList: [],
      historyList: []
    })
    this.getHistory()
  },
  // 双向绑定搜索关键词
  changeSearchKeyword(e) {
    this.setData({
      searchKeyword: e.detail.value
    })
  },
  // 清除搜索
  clearSearch() {
    this.setData({
      searchKeyword: '',
      searchList: []
    })
  },
  // 点击历史搜索
  historySearch(e) {
    let keyword = e.currentTarget.dataset.keyword
    // 本地添加搜索记录 等待下次更新
    this.data.historyList.filter(item => {
      return item.keyword === keyword
    }).length < 1 ?  this.data.historyList.push({
      keyword,
      id: `${Math.random()*1000}${keyword}`
    }) : []
    this.setData({
      searchKeyword: keyword,
      historyList: this.data.historyList
    })
    this.search()
  },
  // 搜索
  search() {
    let _this = this
    modelLogin(getUrl(), (token) => {
      if(!_this.data.searchKeyword) {
        wx.showToast({
          title: '请输入搜索内容',
          icon: 'none'
        })
      } else {
        wx.showLoading({
        title: '加载中'
      })
        sandBox.get({
          api: 'api/course/search',
          data: {
            keyword: this.data.searchKeyword,
            type: 'all'
          },
          header: {
            "authorization": token
          }
        }).then(res => {
          wx.hideLoading()
          res = res.data
          if(res.status) {
            // 没有搜索出信息
            if(res.data.data && res.data.data.length > 0) {
              _this.setData({
                searchList: res.data.data
              })
            } else {
              wx.showToast({
                title: "没有此类搜索信息",
                icon: 'none'
              });
              _this.setData({
                searchList: []
              })
            }
          } else {
            wx.showToast({
              title: res.message || "搜索失败",
              icon: 'none'
            });
          }
        }).catch(e => {
          wx.hideLoading()
          wx.showToast({
            title: "搜索失败",
            icon: 'none'
          });
        })
      }
    })
  },
  // 获取搜索历史
  getHistory () {
    let token = cookieStorage.get("user_token")
    // 用户登录获取token
    if(token) {
      wx.showLoading({
        title: '加载中'
      })
      sandBox.get({
        api: "api/course/search/history",
        header: {
          "authorization": token
        }
      }).then(res => {
        wx.hideLoading()
        res = res.data
        if (res.status) {
          this.setData({
            historyList: res.data
          })
        } else {
          wx.showToast({
            title: "获取搜索历史失败",
            icon: "none"
          });
        }
      }).catch(e => {
        wx.hideLoading()
        wx.showToast({
          title: "获取搜索历史失败",
          icon: "none"
        });
      })
    }
  },
  // 跳转搜索详情
  jumpSearchInfo(e) {
    let item = e.currentTarget.dataset.info;
    switch(item.type) {
      case "课程":
        wx.navigateTo({
          url: '/pages/index/videoinfo/videoinfo?id='+item.id
        })
        break;
      case "活动":
        wx.navigateTo({
          url: '/pages/index/activityinfo/activityinfo?id='+item.id
        })
        break;
      default:
    }
  },
  // 删除搜索历史
  deleteHistory() {
    let _this = this
    modelLogin(getUrl(), (token) => {
      wx.showModal({
        title: '提示',
        content: '删除历史记录不可恢复,确定删除吗?',
        confirmText: '确定',
        cancelText: '取消',
        success: (res) => {
          if (res.confirm) {
            wx.showLoading({
        title: '加载中'
      })
            sandBox.get({
              api: 'api/course/search/removeHistory',
              header: {
                authorization: token
              }
            }).then(res => {
              wx.hideLoading()
              res = res.data
              if (res.status) {
                _this.setData({
                  historyList: []
                })
              } else {
                wx.showToast({
                  title: "清除历史记录失败",
                  icon: "none"
                });
              }
            }).catch(e => {
              wx.hideLoading()
              wx.showToast({
                title: "清除历史记录失败",
                icon: "none"
              });
            })
          }
        }
      })
    })
  }
})