import { sandBox, modelLogin, getUrl, config, changeTime } from '../../../es6/myapp.js';

Page({
  data: {
    todayHistory: [],
    beforeHistory: [],
    historyList: [],
    collectList: [],
    currentPage: 1,
    collectPage: {},
    baseUrl: config.GLOBAL.baseUrl,
    navList: [{
      key: 0,
      value: '观看历史'
    },{
      key: 1,
      value: '我的收藏'
    }],
    activeIndex: 0
  },
  // 查看详情
  jumpInfo(e){
    var id=e.currentTarget.dataset.id;
    var sectionId = e.currentTarget.dataset.sectionid
    var time = e.currentTarget.dataset.time
    if(time === '-1' || Number(time) <0 ) {
      wx.navigateTo({
        url: `/pages/index/videoinfo/videoinfo?id=${id}&sectionId=${sectionId}`
      })
    } else {
      wx.navigateTo({
          url: `/pages/index/videoinfo/videoinfo?id=${id}&sectionId=${sectionId}&time=${time}`
      })
    }
  },
  onLoad(e) {
    if(e.index) {
      this.setData({
        activeIndex: Number(e.index)
      })
    }
    this.init()
  },
  // 初始化
  init() {
    let index = this.data.activeIndex
    if(index === 0) {
      this.getHistoryList()
    } else {
      this.getCollectList()
    }
  },
  // 获取列表
  getHistoryList() {
    modelLogin(getUrl(), (token) => {
      wx.showLoading({
        title: '加载中'
      })
      sandBox.get({
        api: 'api/course/history/me',
        header: {
          authorization: token
        }
      }).then(res => {
        wx.hideLoading()
        res = res.data
        if (res.status) {
          let todayA=[], beforeA=[] 
          if(res.data && res.data.length > 0) {
            // 装换时间显示为 00:00 形式
            res.data.map(item => {
              item.currentTime = changeTime(item.obj_current_time)
              item.totalTime = changeTime(item.obj_total_time)
              // 分组 is_today==1 今天 0 更早
              if(item.is_today === 1) {
                todayA.push(item)
              } else {
                beforeA.push(item)
              }
            })
          }
          this.setData({
            // historyList: res.data ? this.data.historyList.concat(res.data) : this.data.historyList
            todayHistory: this.data.todayHistory.concat(todayA),
            beforeHistory: this.data.beforeHistory.concat(beforeA)
          })
        } else {
          wx.showToast({
            title: res.message || "获取历史记录失败",
            icon: 'none'
          });
        }
      }).catch(e => {
        wx.hideLoading()
        wx.showToast({
          title: "获取历史记录失败",
          icon: 'none'
        });
      })
    })
  },
  // 切换
  toggleNav(e) {
    // 重置
    this.setData({
      historyList: [],
      collectList: [],
      currentPage: 1,
      collectPage: {},
      todayHistory: [],
      beforeHistory: [],
    })
    let index = e.currentTarget.dataset.index
    this.setData({
      activeIndex: Number(index)
    })
    this.init()
  },
  // 获取收藏列表
  getCollectList() {
    let _this = this
    modelLogin(getUrl(), (token) => {
      wx.showLoading({
        title: '加载中'
      })
      sandBox.get({
        api: 'api/course/user/getmecollection',
        data: {
          page: this.data.currentPage
        },
        header: {
          authorization: token
        }
      }).then(res => {
        wx.hideLoading()
        res = res.data
        if (res.status) {
          if(res.data && res.data.length > 0) {
            res.data.map(item => {
              item['is_collect'] = true
            })
          }
          _this.setData({
            collectList: (res.data && res.data.length > 0) ? _this.data.collectList.concat(res.data) : _this.data.collectList,
            collectPage: res.meta.pagination
          })
        } else {
          wx.showToast({
            title: res.message || "获取收藏失败",
            icon: 'none'
          });
        }
      }).catch(e => {
        wx.hideLoading()
        wx.showToast({
          title: "获取收藏失败",
          icon: 'none'
        });
      })
    })
  },
  // 取消收藏
  cancelCollect(e) {
    modelLogin(getUrl(), (token) => {
      let id = e.currentTarget.dataset.id
      wx.showLoading({
        title: '加载中'
      })
      sandBox.post({
        api: 'api/course/cancelCollection',
        data: {
          type: 'course',
          id
        },
        header: {
          authorization: token
        }
      }).then(res => {
        wx.hideLoading()
        res = res.data
        if(res.status) {
          let arr = this.data.collectList
          arr.map(item => {
            if(item.course[0].id === id) {
              item.is_collect = !item.is_collect
            }
          })
          this.setData({
            collectList: arr
          })
        } else {
          wx.showToast({
            title: typeof res.message === 'string' ? res.message : '取消收藏失败',
            icon: 'none'
          })
        }
      }).catch(e => {
        wx.hideLoading()
        wx.showToast({
          title: '取消收藏失败',
          icon: 'none'
        })
      })
    })
  },
  // 收藏
  setCollect(e) {
    modelLogin(getUrl(), (token) => {
      let id = e.currentTarget.dataset.id
      wx.showLoading({
        title: '加载中'
      })
      sandBox.post({
        api: 'api/course/collection',
        data: {
          type: 'course',
          id
        },
        header: {
          authorization: token
        }
      }).then(res => {
        wx.hideLoading()
        res = res.data
        if(res.status) {
          let arr = this.data.collectList
          arr.map(item => {
            if(item.course[0].id === id) {
              item.is_collect = !item.is_collect
            }
          })
          this.setData({
            collectList: arr
          })
        } else {
          wx.showToast({
            title: typeof res.message === 'string' ? res.message : '收藏失败',
            icon: 'none'
          })
        }
      }).catch(e => {
        wx.hideLoading()
        wx.showToast({
          title: '收藏失败',
          icon: 'none'
        })
      })
    })
  }
})