import {sandBox, cookieStorage, is} from '../../../es6/myapp.js';

Page({
  data: {
    type: [],
    course: [],
    shop: [],
    courseIndex: 0,
    shopIndex: 0,
    typeIndex: 0,
    sign_up_name: '',
    sign_up_mobile: '',
    sign_up_age: '',
    sign_up_grade: '',
    sign_up_course: '',
    sign_up_store: '',
    sign_up_type: '',
    submitFlag: false,
    token: ''
  },
  onShow() {
    const token = cookieStorage.get('user_token')
    this.setData({
      token
    })
  },
  onLoad() {
    this.getUpdateInfo()
  },
  // 选择课程
  bindSelectCourse(e) {
    let index = e.detail.value
    this.setData({
      sign_up_course: this.data.course[index].id,
      courseIndex: index
    })
  },
  // 选择店铺
  bindSelectShop(e) {
    let index = e.detail.value
    this.setData({
      sign_up_store: this.data.shop[index].id,
      shopIndex: index
    })
  },
  // 选择类型
  bindSelectType(e) {
    let index = e.detail.value
    this.setData({
      sign_up_type: this.data.type[index].id,
      typeIndex: index
    })
    this.getCourseChild()
  },
  // 双向绑定数据
  modelValue(e) {
    let key = e.currentTarget.dataset.key
    let value = e.detail.value
    this.setData({
      [key]: value
    })
  },
  // 获取picker框信息
  getUpdateInfo() {
    wx.showLoading({
      title: '加载中'
    })
    sandBox.get({
      api: 'api/course/updateUserInfoPage',
    }).then(res => {
      wx.hideLoading()
      res = res.data
      if(res.status) {
        this.setData({
          submitFlag: true
        })
        let types = []
        let shops = []
        if(res.data.course) {
          Object.keys(res.data.course).map(item => {
            types.push({
              id: item,
              name: res.data.course[item]
            })
          })
        }
        if(res.data.shops) {
          Object.keys(res.data.shops).map(item => {
            shops.push({
              id: item,
              name: res.data.shops[item]
            })
          })
        }
        this.setData({
          type: types,
          shop: shops,
          sign_up_type: types[0].id,  // 初始化赋值
          sign_up_store: shops[0].id
        })
        // 根据类型获取课程 type -> course
        this.getCourseChild()
      } else {
        this.setData({
          submitFlag: false
        })
      }
    }).catch(e => {
      wx.hideLoading()
      this.setData({
        submitFlag: false
      })
    })
  },
  // 提交修改
  submit() {
    if(!this.data.submitFlag) {
      wx.showToast({
        title: '初始化数据失败,请退出重试',
        icon: 'none',
        duration: 3000
      })
    } else {
      let { sign_up_name,
            sign_up_mobile,
            sign_up_age,
            sign_up_grade,
            sign_up_course,
            sign_up_store,
            sign_up_type 
          } = this.data
      
      if(!sign_up_name) {
        wx.showToast({
          title: '姓名不能为空',
          icon: 'none'
        })
      } else if(!sign_up_mobile) {
        wx.showToast({
          title: '手机号不能为空',
          icon: 'none'
        })
      } else if(!sign_up_age) {
        wx.showToast({
          title: '年龄不能为空',
          icon: 'none'
        })
      } else if(!sign_up_grade) {
        wx.showToast({
          title: '年级/班级不能为空',
          icon: 'none'
        })
      } else if(!sign_up_course) {
        wx.showToast({
          title: '请选择课程',
          icon: 'none'
        })
      } else if(!sign_up_store) {
        wx.showToast({
          title: '请选择店铺',
          icon: 'none'
        })
      } else if(!sign_up_type) {
        wx.showToast({
          title: '请选择课程类型',
          icon: 'none'
        })
      } else {
        if(!is.mobile(sign_up_mobile)) {
          wx.showToast({
            title: '请输入正确的手机号',
            icon: 'none'
          })
        } else if(!is.age(sign_up_age) || Number(sign_up_age) < 10 || Number(sign_up_age) > 100) {
          wx.showToast({
            title: '输入的年龄必须在10岁在100岁之间',
            icon: 'none'
          })
        } else {
          wx.hideLoading()
          sandBox.post({
            api: 'api/course/me/updateUserInfo',
            data: {
              sign_up_name,
              sign_up_mobile,
              sign_up_age,
              sign_up_grade,
              sign_up_course,
              sign_up_store,
              sign_up_type
            },
            header: {
              authorization: this.data.token
            }
          }).then(res => {
            wx.hideLoading()
            res = res.data
            if(res.status) {
              wx.showToast({
                title:'提交报名成功',
                icon: 'success'
              })
              this.resetParams()
            } else {
              wx.showToast({
                title: '提交报名失败',
                icon: 'none'
              })
            }
          }).catch(e => {
            wx.hideLoading()
            wx.showToast({
              title:'提交报名失败',
              icon: 'none'
            })
          })
        }
      }
    }
  },
  // 重置参数
  resetParams() {
    this.setData({
      sign_up_name: '',
      sign_up_mobile: '',
      sign_up_age: '',
      sign_up_grade: '',
      sign_up_course: '',
      sign_up_store: '',
      sign_up_type:''
    })
  },
  // 根据课程类型获取子元素
  getCourseChild() {
    wx.showLoading({
      title: '加载中'
    })
    sandBox.get({
      api: 'api/course/category/byPidGetSelectOptions',
      data: {
        pid: this.data.sign_up_type
      }
    }).then(res => {
      wx.hideLoading()
      res = res.data
      if(res.status) {
        let courses= []
        if(res.data) {
          Object.keys(res.data).map(item => {
            courses.push({
              id: item,
              name: res.data[item]
            })
          })
        }
        this.setData({
          course: courses,
          sign_up_course: courses[0].id
        })
      } else {
        wx.showToast({
          title: '获取课程类型失败',
          icon: 'none'
        })
      }
    }).catch(e => {
      wx.hideLoading()
      wx.showToast({
        title: '获取课程类型失败',
        icon: 'none'
      })
    })
  }
})