import {config,sandBox,cookieStorage} from '../../../es6/myapp.js';
Page({
    data:{
        detail:"",
        token:"",
        isExchangeVip: false,
        codeVip: '',
        historyList: [],
        baseUrl: config.GLOBAL.baseUrl
    },
    onShow(){
        wx.hideShareMenu()
        // 初始化token
        var token=cookieStorage.get('user_token');
        this.setData({
            token:token
        });
        if(token){
            this.getUserInfo();
            this.getHistoryList()
        }
    },
    // 获取用户信息
    getUserInfo() {
        wx.showLoading({
            title: '加载中'
        })
        sandBox.get({
            api: 'api/course/user',
            header: {
                Authorization: cookieStorage.get('user_token')
            },
        }).then(res => {
            wx.hideLoading()
            res = res.data
            if (res.data.status) {
                this.setData({
                    detail: res.data
                })
                cookieStorage.set('userInfo', res.data)
            } else {
                wx.showToast({
                    title: res.message || "获取信息失败",
                    image: "../../../assets/image/error1.png"
                });
            }
        }).catch(e => {
            wx.hideLoading()
            wx.showToast({
                title: "获取信息失败",
                image: "../../../assets/image/error1.png"
            });
        })
    },
    // 跳转到指定页面
    jumpItem(e) {
        if(!this.data.token){
            return this.jumpLogin();
        }
        var url = e.currentTarget.dataset.url;
        wx.navigateTo({
            url: url
        })
    },
    // 跳转到视频详情
    jumpInfo(e){
        if(!this.data.token){
            return this.jumpLogin();
        }
        var id=e.currentTarget.dataset.id;
        var sectionId = e.currentTarget.dataset.sectionid
        var time = e.currentTarget.dataset.time
        if(time === '-1' || Number(time) <0 ) {
            wx.navigateTo({
              url: `/pages/index/videoinfo/videoinfo?id=${id}&sectionId=${sectionId}`
            })
        } else {
            wx.navigateTo({
                url: `/pages/index/videoinfo/videoinfo?id=${id}&sectionId=${sectionId}&time=${time}`
            })
        }
    },
    // 跳转登录
    jumpLogin(){
        wx.navigateTo({
            url: '/pages/user/register/register'
        })
    },
    // 兑换会员
    exchangeVip() {
        this.setData({
            isExchangeVip: !this.data.isExchangeVip
        })
    },
    // 取消会还会员
    exchangeCancel() {
        this.setData({
            isExchangeVip: false
        })
    },
    // 绑定兑换会员邀请码
    bindExchangeVip (e) {
        let code = e.detail.value
        this.setData({
            codeVip: code
        })
    },
    // 确认兑换
    exchangeSure() {
        if(!this.data.token){
            return this.jumpLogin();
        }
        let codeVip = this.data.codeVip
        if(!codeVip) {
            wx.showToast({
                title: '输入兑换码不能为空',
                icon: 'none'
            })
        } else {
            wx.showLoading({
                title: '加载中'
            })
            sandBox.get({
                api: 'api/course/vip/inviteCodeActiveVip',
                data: {
                    code: codeVip
                },
                header: {
                    authorization: this.data.token
                }
            }).then(res => {
                wx.hideLoading()
                res = res.data
                if(res.status) {
                    this.exchangeCancel()
                    wx.showToast({
                        title: '兑换会员成功',
                        icon: 'success',
                        duration: 3000
                    })
                } else {
                    wx.showToast({
                        title: res.message || '兑换会员失败',
                        icon: 'none'
                    })
                }
            }).catch(e => {
                wx.hideLoading()
                wx.showToast({
                    title: '兑换会员失败',
                    icon: 'none'
                })
            })
        }
    },
    // 获取历史记录
    getHistoryList() {
        sandBox.get({
            api: 'api/course/history/me',
            data: {
                page: 1
            },
            header: {
                authorization: this.data.token
            }
        }).then(res => {
            res = res.data
            if(res.status) {
                this.setData({
                    historyList: (res.data && res.data.length > 0) ? res.data.slice(0,3) : [] 
                })
            }
        }).catch(e => {
            console.log(e)
        })
    },
    getAuthUserInfo(e) {
        if(e.detail.errMsg === 'getUserInfo:ok') {
            sandBox.post({
                api:"api/course/user/update",
                data: {
                    nick_name: e.detail.userInfo.nickName,
                    avatar: e.detail.userInfo.avatarUrl,
                    sex: e.detail.userInfo.gender
                },
                header: {
                    authorization: this.data.token
                }
            }).then(res => {
                res = res.data
                if(res.status) {
                    this.getUserInfo()
                }
            }).catch(e => {

            })
        } else {
            this.showModal({
                title: '授权失败',
                content: '授权用户信息失败,请重新授权',
                showCancel: false
            })
        }
    }
})
